<?php

namespace Drupal\webform_digests\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\webform_digests\WebformDigestsQueueBuilder;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Controller for sending webform digests.
 */
class DigestController extends ControllerBase {

  /**
   * The webform digests queue builder.
   *
   * @var \Drupal\webform_digests\WebformDigestsQueueBuilder
   */
  protected $webformDigestsQueueBuilder;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('webform_digests.queue_builder'),
    );
  }

  /**
   * Constructs a new WebformDigestsCommands object.
   *
   * @param \Drupal\webform_digests\WebformDigestsQueueBuilder $webformDigestsQueueBuilder
   *   The webform digests queue builder.
   */
  public function __construct(WebformDigestsQueueBuilder $webformDigestsQueueBuilder) {
    $this->webformDigestsQueueBuilder = $webformDigestsQueueBuilder;
  }

  /**
   * Send the digests for the day.
   */
  public function sendAction() {
    $queue_count = $this->webformDigestsQueueBuilder->queueSubmissions();
    return new JsonResponse([
      'queued' => $queue_count,
    ]);
  }

}
